@@ -21,9 +21,10 @@ import youtube_dl as youtube_yl  # youtube yownloader
 import ffmpeg
 
 
-__version__ = '0.9.3'
+__version__ = '0.9.4'
 
 
+# TODO: ensure videos are concatenated in the order they're given
 # TODO: command-line argument support
 # TODO: - option to turn off logging for youtube_dl and ffmpeg
 # TODO: handle vod list input through input() after running
@@ -104,7 +105,7 @@ def out_folder_empty(out_folder=args.out_folder, overwrite=args.clear_out_folder
     delete all files in the folder and return True.
     """
     try:
-        out_folder_contents = Path(out_folder).iterdir()
+        out_folder_contents = list(Path(out_folder).iterdir())
     except FileNotFoundError:
         return True
     else:
@@ -237,7 +238,8 @@ def main():
     """
     if not args.no_clear:
         if not out_folder_empty():
-            print(f"The output folder '{args.out_folder}' contains files, please clear it or change the output folder.")
+            print(f"The output folder '{args.out_folder}' contains files, "
+                  'please clear it (--overwrite), change the output folder (--out-folder), or use --no-clear.')
             sys.exit(1)
 
     if not args.video_urls:
